Class: ExampleAppShowcasePageRenderTest

Inherits:
ExampleAppIntegrationTestCase show all
Defined in:
lib/installer_templates/example_app_tests/test/integration/example_app_showcase_page_render_test.rb

Overview

Smoke test for the full FormElementShowcase show page. Covers the display-only helpers (‘header`, `info`, `info_list`) and the show branches of every uploader helper + rich_text.

Constant Summary collapse

SHOWCASE_FIELD_ATTRIBUTES =

All non-header attributes on FormElementShowcase that should each be wrapped in a ‘<turbo-frame id=“form_element_showcase_<id>_<attr>”>`.

%i[
  title
  body_plain_area
  count
  price
  meeting_date
  meeting_time
  birth_month
  start_month
  is_active
  gender
  rating_int
  priority
  priority2
  stars
  attachment
  jingle
  cover
  description
  roles
  created_at
  updated_at
].freeze
SHOWCASE_HEADER_ATTRIBUTES =
%i[
  header_basics
  header_numbers
  header_dates
  header_choices
  header_files
  header_rich
  header_meta
].freeze